@@ -9,27 +9,27 @@ class ExperimentResultsScreen:
 
     def __init__(self):
         button_size = (30, 1)
-        button_pad = ((5, 0), (20, 0))
+        button_pad = ((5, 5), (20, 5))
         self.layout = [[title("Experiment results")],
+                       [sg.Frame(title='Plots', border_width=1, relief='solid', layout=[
+                           [sg.Button('Parallel Coordinates', key='experiment_results_parcoords_button',
+                                      size=button_size, pad=button_pad),
+                            question_mark_button('experiment_results_parcoords_help_button', padding=button_pad)],
+                           [sg.Button('Scatterplot', key='experiment_results_scatterplot_button',
+                                      size=button_size, pad=button_pad),
+                            question_mark_button('experiment_results_scatterplot_help_button', padding=button_pad)],
+                           [sg.Button('Heatmap', key='experiment_results_heatmap_button',
+                                      size=button_size, pad=button_pad),
+                            question_mark_button('experiment_results_heatmap_help_button', padding=button_pad)]])],
                        [sg.Button('Experiment Configuration Information', key='experiment_results_configtable_button',
                                   size=button_size, pad=button_pad),
                         question_mark_button('experiment_results_configtable_help_button', padding=button_pad)],
-                       [sg.Button('Parallel Coordinates', key='experiment_results_parcoords_button',
-                                  size=button_size, pad=button_pad),
-                        question_mark_button('experiment_results_parcoords_help_button', padding=button_pad)],
-                       [sg.Button('Scatterplot', key='experiment_results_scatterplot_button',
-                                  size=button_size, pad=button_pad),
-                        question_mark_button('experiment_results_scatterplot_help_button', padding=button_pad)],
-                       [sg.Button('Heatmap', key='experiment_results_heatmap_button',
-                                  size=button_size, pad=button_pad),
-                        question_mark_button('experiment_results_heatmap_help_button', padding=button_pad)],
                        [sg.Input(key='experiment_results_dummy_export', enable_events=True, visible=False, size=(0, 0)),
                         sg.SaveAs('Save Results', file_types=[("Text Files", "*.txt")],
                                   target='experiment_results_dummy_export', key="experiment_results_save_button",
                                   size=button_size, pad=button_pad),
                         question_mark_button('experiment_results_save_help_button', padding=button_pad)],
-                       [sg.Button('Back to main menu', key='experiment_results_back_button',
-                                  size=button_size, pad=button_pad)]
+                       [sg.Button('Back to main menu', key='experiment_results_back_button', pad=button_pad)]
                        ]
         self.results = None
 
@@ -58,15 +58,25 @@ class ExperimentResultsScreen:
 
         # Help events
         if event == 'experiment_results_configtable_help_button':
-            show_help_window(help_text['config_information'], location=window.CurrentLocation())
+            show_help_window(help_text['config_information'],
+                             location=(window.CurrentLocation()[0] - ((434 - window.size[0]) / 2),
+                                       window.CurrentLocation()[1] + 100))
         if event == 'experiment_results_parcoords_help_button':
-            show_help_window(help_text['parallel_coordinates'], location=window.CurrentLocation())
+            show_help_window(help_text['parallel_coordinates'],
+                             location=(window.CurrentLocation()[0] - ((434 - window.size[0]) / 2),
+                                       window.CurrentLocation()[1] + 100))
         if event == 'experiment_results_scatterplot_help_button':
-            show_help_window(help_text['scatterplot'], location=window.CurrentLocation())
+            show_help_window(help_text['scatterplot'],
+                             location=(window.CurrentLocation()[0] - ((434 - window.size[0]) / 2),
+                                       window.CurrentLocation()[1] + 100))
         if event == 'experiment_results_heatmap_help_button':
-            show_help_window(help_text['heatmap'], location=window.CurrentLocation())
+            show_help_window(help_text['heatmap'],
+                             location=(window.CurrentLocation()[0] - ((434 - window.size[0]) / 2),
+                                       window.CurrentLocation()[1] + 100))
         if event == 'experiment_results_save_help_button':
-            show_help_window(help_text['save_results'], location=window.CurrentLocation())
+            show_help_window(help_text['save_results'],
+                             location=(window.CurrentLocation()[0] - ((434 - window.size[0]) / 2),
+                                       window.CurrentLocation()[1] + 100))
 
     def export_experiment_results(self, values, file_path):
         results_dict = {}
