@@ -8,13 +8,11 @@ from NetLogoDOE.src.gui.help_dictionary import help_text
 class StandardResultsScreen:
 
     def __init__(self):
-        button_size = (20, 1)
-        button_pad = ((5, 0), (20, 0))
+        button_size = (25, 1)
+        button_pad = ((5, 5), (20, 5))
         self.layout = [[title("Standard results")],
-                       [sg.Button('Configuration Information', key='standard_results_configtable_button',
-                                  size=button_size, pad=button_pad),
-                        question_mark_button('standard_results_configtable_help_button', padding=button_pad)],
-                       [sg.Button('Timeseries', key='standard_results_timeseries_button',
+                       [sg.Frame(title='Plots', border_width=1, relief='solid', layout=
+                       [[sg.Button('Timeseries', key='standard_results_timeseries_button',
                                   size=button_size, pad=button_pad),
                         question_mark_button('standard_results_timeseries_help_button', padding=button_pad)],
                        [sg.Button('Boxplot', key='standard_results_boxplot_button',
@@ -28,14 +26,16 @@ class StandardResultsScreen:
                         question_mark_button('standard_results_histogram_help_button', padding=button_pad)],
                        [sg.Button('Distribution plot', key='standard_results_distplot_button',
                                   size=button_size, pad=button_pad),
-                        question_mark_button('standard_results_distplot_help_button', padding=button_pad)],
+                        question_mark_button('standard_results_distplot_help_button', padding=button_pad)]])],
+                       [sg.Button('Standard Configuration Information', key='standard_results_configtable_button',
+                                  size=button_size, pad=button_pad),
+                        question_mark_button('standard_results_configtable_help_button', padding=button_pad)],
                        [sg.Input(key='standard_results_dummy_export', enable_events=True, visible=False, size=(0, 0)),
                         sg.SaveAs('Save Results', file_types=[("Text Files", "*.txt")],
                                   target='standard_results_dummy_export', key="standard_results_save_button",
                                   size=button_size, pad=button_pad),
                         question_mark_button('standard_results_save_help_button', padding=button_pad)],
-                       [sg.Button('Back to main menu', key='standard_results_back_button',
-                                  size=button_size, pad=button_pad)]]
+                       [sg.Button('Back to main menu', key='standard_results_back_button', pad=button_pad)]]
         self.results = None
 
     def check_events(self, event, values, window):
@@ -69,19 +69,33 @@ class StandardResultsScreen:
 
         # Help events
         if event == 'standard_results_configtable_help_button':
-            show_help_window(help_text['config_information'], location=window.CurrentLocation())
+            show_help_window(help_text['config_information'],
+                             location=(window.CurrentLocation()[0] - ((434 - window.size[0]) / 2),
+                                       window.CurrentLocation()[1] + 100))
         if event == 'standard_results_timeseries_help_button':
-            show_help_window(help_text['timeseries'], location=window.CurrentLocation())
+            show_help_window(help_text['timeseries'],
+                             location=(window.CurrentLocation()[0] - ((434 - window.size[0]) / 2),
+                                       window.CurrentLocation()[1] + 100))
         if event == 'standard_results_boxplot_help_button':
-            show_help_window(help_text['boxplot'], location=window.CurrentLocation())
+            show_help_window(help_text['boxplot'],
+                             location=(window.CurrentLocation()[0] - ((434 - window.size[0]) / 2),
+                                       window.CurrentLocation()[1] + 100))
         if event == 'standard_results_violinplot_help_button':
-            show_help_window(help_text['violinplot'], location=window.CurrentLocation())
+            show_help_window(help_text['violinplot'],
+                             location=(window.CurrentLocation()[0] - ((434 - window.size[0]) / 2),
+                                       window.CurrentLocation()[1] + 100))
         if event == 'standard_results_histogram_help_button':
-            show_help_window(help_text['histogram'], location=window.CurrentLocation())
+            show_help_window(help_text['histogram'],
+                             location=(window.CurrentLocation()[0] - ((434 - window.size[0]) / 2),
+                                       window.CurrentLocation()[1] + 100))
         if event == 'standard_results_distplot_help_button':
-            show_help_window(help_text['distributionplot'], location=window.CurrentLocation())
+            show_help_window(help_text['distributionplot'],
+                             location=(window.CurrentLocation()[0] - ((434 - window.size[0]) / 2),
+                                       window.CurrentLocation()[1] + 100))
         if event == 'standard_results_save_help_button':
-            show_help_window(help_text['save_results'], location=window.CurrentLocation())
+            show_help_window(help_text['save_results'],
+                             location=(window.CurrentLocation()[0] - ((434 - window.size[0]) / 2),
+                                       window.CurrentLocation()[1] + 100))
 
     def export_standard_results(self, values, file_path):
         results_dict = {}
