@@ -41,9 +41,13 @@ class ScatterplotScreen:
 
         # Help events
         if event == 'scatterplot_4metric_help_button':
-            show_help_window(help_text['4_metric'], location=window.CurrentLocation())
+            show_help_window(help_text['4_metric'],
+                             location=(window.CurrentLocation()[0] - ((434 - window.size[0]) / 2),
+                                       window.CurrentLocation()[1] + 100))
         if event == 'scatterplot_variable_help_button':
-            show_help_window(help_text['scatterplot_variables'], location=window.CurrentLocation())
+            show_help_window(help_text['scatterplot_variables'],
+                             location=(window.CurrentLocation()[0] - ((434 - window.size[0]) / 2),
+                                       window.CurrentLocation()[1] + 100))
 
     def generate_scatter_plot(self, values, window):
         exp = self.results[0]
